' Author: Hager Harald
' E-Mail: harald.hager@harrys-net.at
' Last change: 30-01-2019 - 00:11
' Used editor: VbsEdit

' Mapping network drives
' Not persistent letter range: I: - S: <= change this comment to stay informed about your pool

  
' Vars
Dim objNetwork, strRemoteServer, iICMPCounter, iICMPTimeout, bConnectionState, iErrorOccured, strDate, bDoStop, iTimeToWaitForConnect

' Objects
Set objNetwork = WScript.CreateObject("WScript.Network")
Set wshShell   = WScript.CreateObject("WScript.Shell")
Set fso        = CreateObject("Scripting.FileSystemObject")

' Vars init (do not change)
iTimeToWaitForConnect = 0   ' Counter how long was waited for connection, but will not be longer then set timeout
iICMPCounter          = 0   ' Counter for ICMP connection tries

' SETTINGS:
strRemoteServer = "\\mynas\"            ' Server where the shares are located (path must be finished with a backslash)
strLogPath      = "E:\Scripts\logs\"    ' Path for the signature log (path must be finished with a backslash)
I_ICMP_TIMEOUT  = 10                    ' Set here the timeout before canceling mapping (in seconds)
I_MAX_LOG_COUNT = 10				    ' Set here the maximal log file count

' SETTING: Shares to map
Function connectShares()
	'        Drive Remote Server    Share              Persistent
	mapDrive "L:", strRemoteServer, "Harald",          True
	mapDrive "I:", strRemoteServer, "MyScans",         True
	mapDrive "K:", strRemoteServer, "AnotherFolder",   True
End Function


' This function will write a log file
Function writeLog (strLogMessage)
	objFile.Write strLogMessage & vbCrLf
End Function


' Getting acutal date and time and format it
strDate = CStr(Now)
strDate = Replace (strDate, ":", "-")
strDate = Replace (strDate, " ", "_")
strDate = Replace (strDate, ".", "-")

' Open the log file
Set objFile = fso.CreateTextFile(strLogPath + "mapLog_" + strDate + ".txt", True)

' logical imperativ EP
WScript.Sleep(5000) ' for very fast booting systems
                    ' to avoid that network is not already loaded

main()

' Write result to the log
Select Case iErrorOccured

    Case 1
	        writeLog ""
	        writeLog "Network error occurred - host " + strRemoteServer + " was unreachable"
	        MsgBox "Warning! - Couldn't map network shares. Please try it manually.",16 , "Connection Error"
	        WScript.Quit 1
	
    Case 2
	        writeLog ""
	        writeLog "One ore more maps were already present"
	        MsgBox "The network drives are alredy mapped.", 64, "Nothing to do"
	        WScript.Quit 2
	        
    Case 0
	        writeLog ""
	        writeLog "Drives successfully mapped"
	        MsgBox "Welcome!", 64, "Ready"
	        WScript.Quit 0
	        
End Select

' Close the log file
objFile.Close


' Main function
Function main()
	
	' Setting here how many tries until timeout
	iErrorOccured      = 0
	iResult            = 0
	
	writeLog "Checking connection..."

   ' Checking connection and map shares	
   If checkConnection (strRemoteServer) < 1 Then
   
			' ... trying to connect shares
			writeLog "Mapping shares..."
			writeLog ""
			
			connectShares()
			
			writeLog ""
			writeLog "Waited " + CStr(iTimeToWaitForConnect) + " seconds for LAN connection to " + strRemoteServer	
   End If 
   
   ' checking log file count
   checkLogSize
End Function


' Checking if a host is online
Function checkConnection(strHost)
 
  bDoStop = False
   
  strHostnameToPing = Replace(strRemoteServer, "\", "")
 
  While bDoStop = False 
  
  	  ' Try ping
      iPing = wshShell.Run("ping -n 1 " & strHostnameToPing, 0, True)
 
 	  ' If ping  was okay ...
      If CStr(iPing) = 0 Then
      		' .. return
      		bDoStop = True
      		checkConnection = 0
      		Exit Function
      Else
           ' try again until timout is reached
  	        iICMPCounter = iICMPCounter + 1 ' Counter for timeout
  	        iTimeToWaitForConnect = iTimeToWaitForConnect + 1
  	        WScript.Sleep (1000) ' Wait one second before do next ping
	
		   ' If timeout is reached exit function
	       If iICMPCounter > I_ICMP_TIMEOUT Then
	       		iErrorOccured   = 1
	     	    checkConnection = 1
	     	    Exit Function
  	       End If
  	  End If 	
  Wend
  
End Function


' Mapping a share to a local drive letter
Function mapDrive(sDriveLetter, strRemoteServer, strName, bPersistent)
    
    ' Vars
    iResult = 0
 
 	' Returns True if the drive already exist
    iResult = fso.DriveExists(sDriveLetter)
    
    ' Mapping
    If iResult = True Then
      	 
       ' Drive letter is already mapped
       writeLog "Share " + strRemoteServer + strName + " is already mapped"
       iErrorOccured = 2
   
       Exit Function
       
    Else
       ' Mapping drive    
       objNetwork.MapNetworkDrive sDriveLetter, strRemoteServer + strName, bPersistent
       writeLog "Share " + strRemoteServer + strName + " mapped"
    End If

End Function


' Checking the size of the log files and deleting the old one
Function checkLogSize()
	Dim files
	iFileCount = 0
	
	Set objFSO = CreateObject("Scripting.FileSystemObject")
	
	Set folder = fso.GetFolder(strLogPath)
	Set files = folder.Files
	
	' get log file count
	For Each item in files
		iFileCount = iFileCount + 1
	Next
	
	' if maximum log file count is reached delete the oldest one
	If (iFileCount > I_MAX_LOG_COUNT) Then
		' Sort files by creation date
	    Set fso  = CreateObject("Scripting.FileSystemObject")
        Set list = CreateObject("ADOR.Recordset")
    
        list.Fields.Append "name", 200, 255
        list.Fields.Append "date", 7
        list.Open

        For Each f In fso.GetFolder(strLogPath).Files
            list.AddNew
            list("name").Value = f.Path
            list("date").Value = f.DateCreated
            list.Update
        Next

        list.MoveFirst
        list.Sort = "date DESC"
        
        iLogCounter = 0
        
        Do Until list.EOF
            iLogCounter = iLogCounter + 1
            
            ' keep count of files as set at I_MAX_LOG_COUNT
            If (iLogCounter > I_MAX_LOG_COUNT) THEN
                ' delete file
                fso.DeleteFile list("name").Value
            End If
                   
            list.MoveNext
        Loop
               
       list.Close
   End If
End Function
